"""
this is the doc string for the pkg_peiwen package.

we modify attributes of the package by editing __init__.py file.
"""

__version__ = "0.1.4" 
# manually set the version of the package here, 
# it should match the version in toml file.