"""
This is the doc for the `pkg_peiwen.function` module.
Put module-level docstring at the top of the module file.
"""

def add_one(x):
    """
    An example function from my example pacakge.

    Add one to the input number.
    """
    return x + 1
